@@ -1,4 +1,4 @@
-from data import *
+from .data import *
 
 
 def beautiful_console(text, text_color=None, highlight_color=None, style=None, blink=False, text_color_degree=0, highlight_color_degree=0):
